==> aliyun-python-sdk-cdn-3.6.7.tar.gz: aliyun-python-sdk-cdn-3.6.7/aliyunsdkcdn/request/v20180510/DescribeConfigGroupDetailRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcdn.endpoint import endpoint_data

class DescribeConfigGroupDetailRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cdn', '2018-05-10', 'DescribeConfigGroupDetail')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ConfigGroupName(self):
		return self.get_query_params().get('ConfigGroupName')

	def set_ConfigGroupName(self,ConfigGroupName):
		self.add_query_param('ConfigGroupName',ConfigGroupName)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)

	def get_ConfigGroupId(self):
		return self.get_query_params().get('ConfigGroupId')

	def set_ConfigGroupId(self,ConfigGroupId):
		self.add_query_param('ConfigGroupId',ConfigGroupId)

==> aliyun-python-sdk-cdn-3.7.7.tar.gz: aliyun-python-sdk-cdn-3.7.7/aliyunsdkcdn/request/v20180510/DescribeConfigGroupDetailRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcdn.endpoint import endpoint_data

class DescribeConfigGroupDetailRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cdn', '2018-05-10', 'DescribeConfigGroupDetail')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ConfigGroupName(self): # String
		return self.get_query_params().get('ConfigGroupName')

	def set_ConfigGroupName(self, ConfigGroupName):  # String
		self.add_query_param('ConfigGroupName', ConfigGroupName)
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_ConfigGroupId(self): # String
		return self.get_query_params().get('ConfigGroupId')

	def set_ConfigGroupId(self, ConfigGroupId):  # String
		self.add_query_param('ConfigGroupId', ConfigGroupId)
